macro_rules! routes {
($($tokens:tt)*) => { ... };
}Expand description
A marker macro to define routes within a #[controller] impl block.
The #[controller] procedural macro is responsible for parsing this.
macro_rules! routes {
($($tokens:tt)*) => { ... };
}A marker macro to define routes within a #[controller] impl block.
The #[controller] procedural macro is responsible for parsing this.